@@ -26,6 +26,10 @@
 #    define _STLP_DONT_POP_HEADER_ID
 #  endif
 
+#  if defined(_STLP_WCE_EVC3)
+struct _exception;
+#  endif
+
 #  include _STLP_NATIVE_C_HEADER(stdarg.h)
 
 #  if (_STLP_OUTERMOST_HEADER_ID == 0x261)
@@ -37,8 +41,3 @@
 #    endif
 #  endif
 #endif /* RC_INVOKED */
-
-/* Local Variables:
- * mode:C++
- * End:
- */
