@@ -317,8 +317,18 @@ struct _Rope_RopeRep
 {
   typedef _Rope_RopeRep<_CharT, _Alloc> _Self;
 public:
+  //
+  // GAB: 11/09/05
+  //
+  // "__ROPE_DEPTH_SIZE" is set to one more then the "__ROPE_MAX_DEPTH".
+  // This was originally just an addition of "__ROPE_MAX_DEPTH + 1" 
+  // but this addition causes the sunpro compiler to complain about 
+  // multiple declarations during the initialization of "_S_min_len". 
+  // Changed to be a fixed value and the sunpro compiler appears to 
+  // be happy???
+  //
 #  define __ROPE_MAX_DEPTH  45
-#  define __ROPE_DEPTH_SIZE __ROPE_MAX_DEPTH + 1
+#  define __ROPE_DEPTH_SIZE 46 // __ROPE_MAX_DEPTH + 1
   enum { _S_max_rope_depth = __ROPE_MAX_DEPTH };
   enum _Tag {_S_leaf, _S_concat, _S_substringfn, _S_function};
   // Apparently needed by VC++
@@ -1025,7 +1035,7 @@ inline ptrdiff_t* distance_type(const _Rope_const_iterator<_CharT,_Alloc>&) { re
 #endif /* _STLP_USE_OLD_HP_ITERATOR_QUERIES */
 
 template <class _CharT, class _Alloc, class _CharConsumer>
-bool _S_apply_to_pieces(_CharConsumer __c,
+bool _S_apply_to_pieces(_CharConsumer& __c,
                         _Rope_RopeRep<_CharT, _Alloc> *__r,
                         size_t __begin, size_t __end);
                         // begin and end are assumed to be in range.
@@ -1130,10 +1140,10 @@ public:
 #ifdef _STLP_MEMBER_TEMPLATES
   template <class _CharConsumer>
 #else
-  typedef _Rope_char_consumer<_CharT>& _CharConsumer;
+  typedef _Rope_char_consumer<_CharT> _CharConsumer;
 #endif
   void apply_to_pieces(size_t __begin, size_t __end,
-                       _CharConsumer __c) const {
+                       _CharConsumer& __c) const {
     _S_apply_to_pieces(__c, _M_tree_ptr._M_data, __begin, __end);
   }
 
