@@ -15,9 +15,8 @@ struct ref_locale {
   const char *decimal_point;
   const char *thousands_sep;
   const char *money_int_prefix;
+  const char *money_int_prefix_old;
   const char *money_prefix;
-  const char *money_int_suffix;
-  const char *money_int_suffix_old;
   const char *money_suffix;
   const char *money_decimal_point;
   const char *money_thousands_sep;
@@ -27,17 +26,17 @@ struct ref_locale {
 // It undefined in any case!!!!!
 
 static const ref_locale tested_locales[] = {
-//{  name,         decimal_point, thousands_sep, money_int_prefix, money_prefix, money_int_suffix, money_int_suffix_old, money_suffix, money_decimal_point, money_thousands_sep},
-  { "fr_FR",       ",",           "\xa0",        "",               "",           "EUR ",           "FRF ",               "",           ",",                
+//{  name,         decimal_point, thousands_sep, money_int_prefix, money_int_prefix_old, money_prefix, money_suffix, money_decimal_point, money_thousands_sep},
+  { "fr_FR",       ",",           "\xa0",        "EUR ",           "FRF ",               "",           "",           ",",                
 #if defined (WIN32)
-                                                                                                                                                            "\xa0" },
+                                                                                                                                          "\xa0" },
 #else
-                                                                                                                                                            " " },
+                                                                                                                                          " " },
 #endif
-  { "ru_RU.koi8r", ",",           ".",           "",               "",           "RUR ",           "",                   "",           ".",                 " " },
-  { "en_GB",       ".",           ",",           "GBP ",           "\xa3",       "",               "",                   "",           ".",                 "," },
-  { "en_US",       ".",           ",",           "USD ",           "$",          "",               "",                   "",           ".",                 "," },
-  { "C",           ".",           ",",           "",               "",           "",               "",                   "",           " ",                 " " },
+  { "ru_RU.koi8r", ",",           ".",           "RUR ",           "",                   "",           "\xd2\xd5\xc2", ".",               " " },
+  { "en_GB",       ".",           ",",           "GBP ",           "",                   "\xa3",       "",           ".",                 "," },
+  { "en_US",       ".",           ",",           "USD ",           "",                   "$",          "",           ".",                 "," },
+  { "C",           ".",           ",",           "",               "",                   "",           "",           " ",                 " " },
 };
 
 
@@ -55,6 +54,8 @@ class LocaleTest : public CPPUNIT_NS::TestCase
   CPPUNIT_TEST(collate_facet);
   CPPUNIT_TEST(ctype_facet);
   CPPUNIT_TEST(locale_init_problem);
+  CPPUNIT_TEST(money_put_X_bug);
+  CPPUNIT_TEST(default_locale);
   CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -66,6 +67,8 @@ public:
   void collate_facet();
   void ctype_facet();
   void locale_init_problem();
+  void money_put_X_bug();
+  void default_locale();
 private:
   void _loc_has_facet( const locale&, const ref_locale& );
   void _num_put_get( const locale&, const ref_locale& );
@@ -74,6 +77,7 @@ private:
   void _collate_facet( const locale&, const ref_locale& );
   void _ctype_facet( const locale&, const ref_locale& );
   void _locale_init_problem( const locale&, const ref_locale& );
+  void _money_put_X_bug( const locale&, const ref_locale& );
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(LocaleTest);
@@ -132,22 +136,22 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
 {
   money_put<char> const& fmp = use_facet<money_put<char> >(loc);
   money_get<char> const& fmg = use_facet<money_get<char> >(loc);
-  moneypunct<char, true> const& intl_fmp = use_facet<moneypunct<char, true> >(loc);
 
   ostringstream ostr;
   ostr.imbue(loc);
   ostr << showbase;
 
-  //Check a positive value
+  //Check a positive value (international format)
   {
     string str_res;
     //money_put
     {
+      moneypunct<char, true> const& intl_fmp = use_facet<moneypunct<char, true> >(loc);
+
       ostreambuf_iterator<char> res = fmp.put(ostr, true, ostr, ' ', 123456);
 
       CPPUNIT_ASSERT( !res.failed() );
       str_res = ostr.str();
-      //cout << str_res << endl;
 
       size_t fieldIndex = 0;
       size_t index = 0;
@@ -172,10 +176,17 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
       string::size_type p = strlen( rl.money_int_prefix );
       if (p != 0) {
         CPPUNIT_ASSERT( intl_fmp.pos_format().field[fieldIndex] == money_base::symbol );
-        CPPUNIT_ASSERT( str_res.substr(index, p) == rl.money_int_prefix );
-        index += p;
+        string::size_type p_old = strlen( rl.money_int_prefix_old );
+        CPPUNIT_ASSERT( (str_res.substr(index, p) == rl.money_int_prefix) ||
+                        ((p_old != 0) && (str_res.substr(index, p_old) ==  rl.money_int_prefix_old)) );
+        if ( str_res.substr(index, p) == rl.money_int_prefix ) {
+          index += p;
+        } else {
+          index += p_old;
+        }
         ++fieldIndex;
       }
+      
       // space after currency
       if (intl_fmp.pos_format().field[fieldIndex] == money_base::space ||
           intl_fmp.pos_format().field[fieldIndex] == money_base::none) {
@@ -216,27 +227,6 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
         ++fieldIndex;
       }
 
-      // iternational currency abbreviation, if it sacceeds value
-
-      // Oh, RUR typed wrong here, but test pass this:
-      // it prints '1 234.56 RUR ' (see space after RUR)
-      // This is due to intl_fmp.curr_symbol() == "RUR ".
-      // Sources I see isn't clear say about the format...
-
-      p = strlen( rl.money_int_suffix );
-      if ( p != 0 ) {
-        CPPUNIT_ASSERT( intl_fmp.pos_format().field[fieldIndex] == money_base::symbol );
-        string::size_type p_old = strlen( rl.money_int_suffix_old );
-        CPPUNIT_ASSERT( (str_res.substr(index, p) == rl.money_int_suffix) || 
-                        ((p_old != 0) && (str_res.substr(index, p_old) ==  rl.money_int_suffix_old)) );
-        if ( str_res.substr(index, p) == rl.money_int_suffix ) {
-          index += p;
-        } else {
-          index += p_old;
-        }
-        ++fieldIndex;
-      }
-
       // sign
       if (intl_fmp.pos_format().field[fieldIndex] == money_base::sign) {
         ++fieldIndex;
@@ -264,7 +254,7 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
   }
 
   ostr.str("");
-  //Check a negative value:
+  //Check a negative value (national format)
   {
     moneypunct<char, false> const& dom_fmp = use_facet<moneypunct<char, false> >(loc);
     string str_res;
@@ -278,7 +268,7 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
       size_t fieldIndex = 0;
       size_t index = 0;
 
-      if (intl_fmp.neg_format().field[fieldIndex] == money_base::sign) {
+      if (dom_fmp.neg_format().field[fieldIndex] == money_base::sign) {
         CPPUNIT_ASSERT( str_res.substr(index, dom_fmp.negative_sign().size()) == dom_fmp.negative_sign() );
         index += dom_fmp.negative_sign().size();
         ++fieldIndex;
@@ -290,8 +280,8 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
         index += p;
         ++fieldIndex;
       }
-      if (intl_fmp.neg_format().field[fieldIndex] == money_base::space ||
-          intl_fmp.neg_format().field[fieldIndex] == money_base::none) {
+      if (dom_fmp.neg_format().field[fieldIndex] == money_base::space ||
+          dom_fmp.neg_format().field[fieldIndex] == money_base::none) {
         CPPUNIT_ASSERT( str_res[index++] == ' ' );
         ++fieldIndex;
       }
@@ -312,16 +302,17 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
 
       //space cannot be last:
       if ((fieldIndex < 3) &&
-          intl_fmp.neg_format().field[fieldIndex] == money_base::space) {
+          dom_fmp.neg_format().field[fieldIndex] == money_base::space) {
         CPPUNIT_ASSERT( str_res[index++] == ' ' );
         ++fieldIndex;
       }
+
       if (fieldIndex == 3) {
         //If none is last we should not add anything to the resulting string:
-        if (intl_fmp.neg_format().field[fieldIndex] == money_base::none) {
+        if (dom_fmp.neg_format().field[fieldIndex] == money_base::none) {
           CPPUNIT_ASSERT( index == str_res.size() );
-        }
-        else {
+        } else {
+          CPPUNIT_ASSERT( dom_fmp.neg_format().field[fieldIndex] == money_base::symbol );
           CPPUNIT_ASSERT( str_res.substr(index, strlen(rl.money_suffix)) == rl.money_suffix );
         }
       }
@@ -350,6 +341,145 @@ void LocaleTest::_money_put_get( const locale& loc, const ref_locale& rl )
   }
 }
 
+
+// Test for bug in case when number of digits in value less then number
+// of digits in fraction. I.e. '9' should be printed as '0.09',
+// if x.frac_digits() == 2.
+
+void LocaleTest::_money_put_X_bug( const locale& loc, const ref_locale& rl )
+{
+  money_put<char> const& fmp = use_facet<money_put<char> >(loc);
+
+  ostringstream ostr;
+  ostr.imbue(loc);
+  ostr << showbase;
+
+  // ostr.str("");
+  // Check value with one decimal digit:
+  {
+    moneypunct<char, false> const& dom_fmp = use_facet<moneypunct<char, false> >(loc);
+    string str_res;
+    // Check money_put
+    {
+      ostreambuf_iterator<char> res = fmp.put(ostr, false, ostr, ' ', 9);
+
+      CPPUNIT_ASSERT( !res.failed() );
+      str_res = ostr.str();
+
+      size_t fieldIndex = 0;
+      size_t index = 0;
+
+      if (dom_fmp.pos_format().field[fieldIndex] == money_base::sign) {
+        CPPUNIT_ASSERT( str_res.substr(index, dom_fmp.positive_sign().size()) == dom_fmp.positive_sign() );
+        index += dom_fmp.positive_sign().size();
+        ++fieldIndex;
+      }
+
+      string::size_type p = strlen( rl.money_prefix );
+      if (p != 0) {
+        CPPUNIT_ASSERT( str_res.substr(index, p) == rl.money_prefix );
+        index += p;
+        ++fieldIndex;
+      }
+      if (dom_fmp.neg_format().field[fieldIndex] == money_base::space ||
+          dom_fmp.neg_format().field[fieldIndex] == money_base::none) {
+        CPPUNIT_ASSERT( str_res[index++] == ' ' );
+        ++fieldIndex;
+      }
+      if (dom_fmp.frac_digits() != 0) {
+        CPPUNIT_ASSERT( str_res[index++] == '0' );
+        CPPUNIT_ASSERT( str_res[index++] == dom_fmp.decimal_point() );
+        for ( int fd = 1; fd < dom_fmp.frac_digits(); ++fd ) {
+          CPPUNIT_ASSERT( str_res[index++] == '0' );
+        }
+      }
+      CPPUNIT_ASSERT( str_res[index++] == '9' );
+      ++fieldIndex;
+
+      //space cannot be last:
+      if ((fieldIndex < 3) &&
+          dom_fmp.neg_format().field[fieldIndex] == money_base::space) {
+        CPPUNIT_ASSERT( str_res[index++] == ' ' );
+        ++fieldIndex;
+      }
+
+      if (fieldIndex == 3) {
+        //If none is last we should not add anything to the resulting string:
+        if (dom_fmp.neg_format().field[fieldIndex] == money_base::none) {
+          CPPUNIT_ASSERT( index == str_res.size() );
+        } else {
+          CPPUNIT_ASSERT( dom_fmp.neg_format().field[fieldIndex] == money_base::symbol );
+          CPPUNIT_ASSERT( str_res.substr(index, strlen(rl.money_suffix)) == rl.money_suffix );
+        }
+      }
+    }
+  }
+
+  ostr.str("");
+  // Check value with two decimal digit:
+  {
+    moneypunct<char, false> const& dom_fmp = use_facet<moneypunct<char, false> >(loc);
+    string str_res;
+    // Check money_put
+    {
+      ostreambuf_iterator<char> res = fmp.put(ostr, false, ostr, ' ', 90);
+
+      CPPUNIT_ASSERT( !res.failed() );
+      str_res = ostr.str();
+
+      size_t fieldIndex = 0;
+      size_t index = 0;
+
+      if (dom_fmp.pos_format().field[fieldIndex] == money_base::sign) {
+        CPPUNIT_ASSERT( str_res.substr(index, dom_fmp.positive_sign().size()) == dom_fmp.positive_sign() );
+        index += dom_fmp.positive_sign().size();
+        ++fieldIndex;
+      }
+
+      string::size_type p = strlen( rl.money_prefix );
+      if (p != 0) {
+        CPPUNIT_ASSERT( str_res.substr(index, p) == rl.money_prefix );
+        index += p;
+        ++fieldIndex;
+      }
+      if (dom_fmp.neg_format().field[fieldIndex] == money_base::space ||
+          dom_fmp.neg_format().field[fieldIndex] == money_base::none) {
+        CPPUNIT_ASSERT( str_res[index++] == ' ' );
+        ++fieldIndex;
+      }
+      if (dom_fmp.frac_digits() != 0) {
+        CPPUNIT_ASSERT( str_res[index++] == '0' );
+        CPPUNIT_ASSERT( str_res[index++] == dom_fmp.decimal_point() );
+        for ( int fd = 1; fd < dom_fmp.frac_digits() - 1; ++fd ) {
+          CPPUNIT_ASSERT( str_res[index++] == '0' );
+        }
+      }
+      CPPUNIT_ASSERT( str_res[index++] == '9' );
+      if (dom_fmp.frac_digits() != 0) {
+        CPPUNIT_ASSERT( str_res[index++] == '0' );
+      }
+      ++fieldIndex;
+
+      //space cannot be last:
+      if ((fieldIndex < 3) &&
+          dom_fmp.neg_format().field[fieldIndex] == money_base::space) {
+        CPPUNIT_ASSERT( str_res[index++] == ' ' );
+        ++fieldIndex;
+      }
+
+      if (fieldIndex == 3) {
+        //If none is last we should not add anything to the resulting string:
+        if (dom_fmp.neg_format().field[fieldIndex] == money_base::none) {
+          CPPUNIT_ASSERT( index == str_res.size() );
+        } else {
+          CPPUNIT_ASSERT( dom_fmp.neg_format().field[fieldIndex] == money_base::symbol );
+          CPPUNIT_ASSERT( str_res.substr(index, strlen(rl.money_suffix)) == rl.money_suffix );
+        }
+      }
+    }
+  }
+}
+
 void LocaleTest::_time_put_get( const locale& loc, const ref_locale&)
 {
   const time_put<char>& tmp = use_facet<time_put<char> >(loc);
@@ -397,8 +527,6 @@ void LocaleTest::_time_put_get( const locale& loc, const ref_locale&)
   ret = tmp.put(ostrX, ostrX, ' ', &xmas, format.data(), format.data() + format.size());
   CPPUNIT_ASSERT( !ret.failed() );
 
-  //cerr << ostrX.str() << endl;
-
   istringstream istrX( ostrX.str() );
   istreambuf_iterator<char> j( istrX );
 
@@ -660,6 +788,10 @@ void LocaleTest::money_put_get() {
   test_supported_locale(*this, &LocaleTest::_money_put_get);
 }
 
+void LocaleTest::money_put_X_bug() {
+  test_supported_locale(*this, &LocaleTest::_money_put_X_bug);
+}
+
 void LocaleTest::time_put_get() {
   test_supported_locale(*this, &LocaleTest::_time_put_get);
 }
@@ -717,7 +849,6 @@ void LocaleTest::_locale_init_problem( const locale& loc, const ref_locale&)
   }
   catch ( runtime_error& ) {
     CPPUNIT_ASSERT( false );
-    // cerr << "-- " << err.what() << endl;
   }
   catch ( ... ) {
    CPPUNIT_ASSERT( false );
@@ -739,4 +870,9 @@ void LocaleTest::_locale_init_problem( const locale& loc, const ref_locale&)
 #  endif
 }
 
+void LocaleTest::default_locale()
+{
+  locale loc( "" );
+}
+
 #endif
